        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 19 <br>4,5,6,12,17,18,19,23,30,31,32,37,39,40,42,43,45,46,48';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,7,8,9,10,11,15,16,21,24,26,28,29,33,35,38,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 15 <br>1,2,3,13,14,20,22,25,27,34,36,41,44,47,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 19 <br>4,5,6,12,17,18,19,23,30,31,32,37,39,40,42,43,45,46,48';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,7,8,9,10,11,15,16,21,24,26,28,29,33,35,38,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 15 <br>1,2,3,13,14,20,22,25,27,34,36,41,44,47,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 19 <br>4,5,6,12,17,18,19,23,30,31,32,37,39,40,42,43,45,46,48';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,7,8,9,10,11,15,16,21,24,26,28,29,33,35,38,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 15 <br>1,2,3,13,14,20,22,25,27,34,36,41,44,47,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 19 <br>4,5,6,12,17,18,19,23,30,31,32,37,39,40,42,43,45,46,48';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,7,8,9,10,11,15,16,21,24,26,28,29,33,35,38,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 15 <br>1,2,3,13,14,20,22,25,27,34,36,41,44,47,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 19 <br>4,5,6,12,17,18,19,23,30,31,32,37,39,40,42,43,45,46,48';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,7,8,9,10,11,15,16,21,24,26,28,29,33,35,38,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260515 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 15 <br>1,2,3,13,14,20,22,25,27,34,36,41,44,47,50';}
}
